@@ -19,8 +19,8 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
 
-#ifndef _SAMBA_ANALYZER_H_
-#define _SAMBA_ANALYZER_H_
+#ifndef SAMBA_ANALYZER_H
+#define SAMBA_ANALYZER_H
 
 #include <KLocalizedString>
 
@@ -40,12 +40,12 @@ public:
     explicit SambaAnalyzer(LogMode *logMode)
         : FileAnalyzer(logMode)
     {
-        currentLogLine = NULL;
+        currentLogLine = nullptr;
     }
 
     virtual ~SambaAnalyzer() {}
 
-    LogViewColumns initColumns() Q_DECL_OVERRIDE
+    LogViewColumns initColumns() override
     {
         LogViewColumns columns;
 
@@ -59,9 +59,9 @@ public:
     }
 
 protected:
-    LogFileReader *createLogFileReader(const LogFile &logFile) Q_DECL_OVERRIDE { return new LocalLogFileReader(logFile); }
+    LogFileReader *createLogFileReader(const LogFile &logFile) override { return new LocalLogFileReader(logFile); }
 
-    Analyzer::LogFileSortMode logFileSortMode() Q_DECL_OVERRIDE { return Analyzer::AscendingSortedLogFile; }
+    Analyzer::LogFileSortMode logFileSortMode() override { return Analyzer::AscendingSortedLogFile; }
 
     /*
      * Log line examples :
@@ -84,7 +84,7 @@ protected:
      * that the last file line is the last message of the current log line.
      * So the previous last line will be returned at the next file update,
      */
-    LogLine *parseMessage(const QString &logLine, const LogFile &originalLogFile) Q_DECL_OVERRIDE
+    LogLine *parseMessage(const QString &logLine, const LogFile &originalLogFile) override
     {
         QString line(logLine);
 
@@ -143,7 +143,7 @@ protected:
         }
 
         if (line.indexOf(QLatin1String("  ")) != -1) {
-            if (currentLogLine != NULL) {
+            if (currentLogLine != nullptr) {
                 QStringList list = currentLogLine->logItems();
 
                 // A line has already been added
@@ -166,4 +166,4 @@ protected:
     LogLine *currentLogLine;
 };
 
-#endif // _SAMBA_ANALYZER_H_
+#endif // _SAMBA_ANALYZER_H
