@@ -47,7 +47,7 @@ class SystemAnalyzerTest : public QObject
 {
     Q_OBJECT
 
-private slots:
+private Q_SLOTS:
 
     void initTestCase();
 
@@ -74,7 +74,7 @@ void SystemAnalyzerTest::initTestCase()
 
 void SystemAnalyzerTest::testOneLine()
 {
-    LogViewModel *model = NULL;
+    LogViewModel *model = nullptr;
 
     Analyzer *systemAnalyzer = testUtil.createAnalyzer(QStringLiteral("systemLogMode"), &model);
     QVERIFY(systemAnalyzer);
@@ -105,7 +105,7 @@ void SystemAnalyzerTest::testOneLine()
 
 void SystemAnalyzerTest::testTwoLines()
 {
-    LogViewModel *model = NULL;
+    LogViewModel *model = nullptr;
 
     Analyzer *systemAnalyzer = testUtil.createAnalyzer(QStringLiteral("systemLogMode"), &model);
     QVERIFY(systemAnalyzer);
@@ -128,7 +128,7 @@ void SystemAnalyzerTest::testTwoLines()
 
 void SystemAnalyzerTest::testMultipleLines()
 {
-    LogViewModel *model = NULL;
+    LogViewModel *model = nullptr;
 
     Analyzer *systemAnalyzer = testUtil.createAnalyzer(QStringLiteral("systemLogMode"), &model);
     QVERIFY(systemAnalyzer);
@@ -186,7 +186,7 @@ void SystemAnalyzerTest::testMultipleLines()
 
 void SystemAnalyzerTest::testStrangeLines()
 {
-    LogViewModel *model = NULL;
+    LogViewModel *model = nullptr;
 
     Analyzer *systemAnalyzer = testUtil.createAnalyzer(QStringLiteral("systemLogMode"), &model);
     QVERIFY(systemAnalyzer);
@@ -262,7 +262,7 @@ void SystemAnalyzerTest::testStrangeLines()
 
 void SystemAnalyzerTest::testDeleteProcessIdentifier()
 {
-    LogViewModel *model = NULL;
+    LogViewModel *model = nullptr;
 
     Analyzer *systemAnalyzer = testUtil.createAnalyzer(QStringLiteral("systemLogMode"), &model);
     QVERIFY(systemAnalyzer);
@@ -297,7 +297,7 @@ void SystemAnalyzerTest::testDeleteProcessIdentifier()
 
 void SystemAnalyzerTest::testMaxLines()
 {
-    LogViewModel *model = NULL;
+    LogViewModel *model = nullptr;
 
     Analyzer *systemAnalyzer = testUtil.createAnalyzer(QStringLiteral("systemLogMode"), &model);
     QVERIFY(systemAnalyzer);
@@ -357,14 +357,14 @@ void SystemAnalyzerTest::compareWithMinTime(QList<LogLine *> logLines, const QDa
             QFAIL(QString::fromLatin1("The line '%1' has a lesser time than the required min time (%2)")
                       .arg(logLine->logItems().join(QLatin1String(" ")))
                       .arg(logLine->time().toString())
-                      .toUtf8());
+                      .toUtf8().constData());
         }
     }
 }
 
 void SystemAnalyzerTest::testRemoveDuplicates()
 {
-    LogViewModel *model = NULL;
+    LogViewModel *model = nullptr;
 
     Analyzer *systemAnalyzer = testUtil.createAnalyzer(QStringLiteral("systemLogMode"), &model);
     QVERIFY(systemAnalyzer);
